@@ -17,7 +17,7 @@ This module provides importable constants for namespaces.
 To use, add "from case_utils.namespace import *".  Namespace variables starting with "NS_" are imported.  As needs are demonstrated in CASE tooling (both in case_utils and from downstream requests), namespaces will also be imported from rdflib for a consistent "NS_*" spelling.
 """
 
-__version__ = "0.2.0"
+__version__ = "0.2.1"
 
 import rdflib
 
@@ -37,6 +37,9 @@ NS_CO = rdflib.Namespace("http://purl.org/co/")
 NS_UCO_ACTION = rdflib.Namespace(
     "https://ontology.unifiedcyberontology.org/uco/action/"
 )
+NS_UCO_ANALYSIS = rdflib.Namespace(
+    "https://ontology.unifiedcyberontology.org/uco/analysis/"
+)
 NS_UCO_CONFIGURATION = rdflib.Namespace(
     "https://ontology.unifiedcyberontology.org/uco/configuration/"
 )
